@@ -2,9 +2,12 @@
 """
 from invoke import run
 
+from .settings import config
+
 
 def build_dists():
-    run('python setup.py sdist bdist_wheel')
+    command = config.get('semantic_release', 'build_command')
+    run(command)
 
 
 def remove_dists(path: str):
